@@ -592,6 +592,75 @@ def test_get_arrivals_departures_observations_by_route():
     assert sent_req.querystring["routes"] == ["401,404"]
 
 
+@httpretty.activate
+def test_get_arrivals_departures_observations_by_vehicle():
+    agency = "test_agency"
+    target_date = date(2023, 10, 1)
+    client = SwiftlyAPIClient(agency_key=agency, api_key="test_api_key")
+
+    url = client._format_url(client.ARRIVAL_DEPARTURE_OBSERVATIONS)
+
+    httpretty.register_uri(
+        httpretty.GET,
+        url,
+        responses=[
+            httpretty.Response(
+                body="""block_id,trip_id,route_id,route_short_name,direction_id,stop_id,stop_name,stop_code,trip_headsign,departure_vehicle_id,arrival_vehicle_id,stop_order,gtfs_stop_sequence,trip_start_time,is_last_stop_of_trip,is_first_stop_of_trip,adjustment_ids,adjustment_types,adjustment_effects,schedule_adherence_secs,scheduled_arrival_time,scheduled_departure_time,observed_arrival_time,observed_departure_time,is_schedule_adherence_stop,service_date
+401-1,t_5940767_b_83572_tn_6,401,401,0,2561195,Mall in Columbia,40000,Clary's Forest,123,123,0,1,14:00:00,false,true,,,,,14:00:00,14:00:00,,,true,2024-12-01
+401-1,t_5940768_b_83572_tn_10,401,401,1,2561170,Howard County Hospital East (Southbound),43019,Mall in Columbia,123,123,7,8,18:20:00,false,false,,,,,18:25:43,18:25:43,,,false,2024-12-01
+401-1,t_5940768_b_83572_tn_10,401,401,1,2561169,Howard County Hospital South (Southbound),43020,Mall in Columbia,123,123,8,9,18:20:00,false,false,,,,,18:26:00,18:26:00,,,false,2024-12-01
+                """,
+                status=200,
+            ),
+        ],
+    )
+
+    df = client.get_arrivals_departures_observations(target_date, vehicles=["123"])
+
+    expected_df = pd.DataFrame(
+        {
+            "block_id": ["401-1", "401-1", "401-1"],
+            "trip_id": [
+                "t_5940767_b_83572_tn_6",
+                "t_5940768_b_83572_tn_10",
+                "t_5940768_b_83572_tn_10",
+            ],
+            "route_id": [401, 401, 401],
+            "route_short_name": [401, 401, 401],
+            "direction_id": [0, 1, 1],
+            "scheduled_arrival_time": [
+                "14:00:00",
+                "18:25:43",
+                "18:26:00",
+            ],
+            "service_date": [
+                "2024-12-01",
+                "2024-12-01",
+                "2024-12-01",
+            ],
+            "departure_vehicle_id": [123, 123, 123],
+        }
+    )
+
+    # just compare some specific columns
+    assert df[
+        [
+            "block_id",
+            "trip_id",
+            "route_id",
+            "route_short_name",
+            "direction_id",
+            "scheduled_arrival_time",
+            "service_date",
+            "departure_vehicle_id",
+        ]
+    ].equals(expected_df)
+
+    sent_req = httpretty.last_request()
+    assert sent_req.querystring["startDate"] == ["10-01-2023"]
+    assert sent_req.querystring["vehicles"] == ["123"]
+
+
 @httpretty.activate
 def test_get_arrivals_departures_observations_invalid_date_range():
     agency = "test_agency"
